@@ -1,24 +1,15 @@
-// #include <RcppArmadillo.h>
-// #include <iostream>
-// #include <vector>
-// #include <algorithm>
-// #include "bigmemory/BigMatrix.h"
-// #include "bigmemory/MatrixAccessor.hpp"
-// #include "bigmemory/bigmemoryDefines.h"
-// #include <time.h>
-// #include <omp.h>
 
 #include "utilities.h"
 
 int check_rest_set(int *e1, int *e2, vector<double> &z, XPtr<BigMatrix> xpMat, 
                    int *row_idx, vector<int> &col_idx,
-                   NumericVector &center, NumericVector &scale,
+                   NumericVector &center, NumericVector &scale, double *a,
                    double lambda, double sumResid, double alpha, double *r, 
                    double *m, int n, int p);
 
 int check_strong_set(int *e1, int *e2, vector<double> &z, XPtr<BigMatrix> xpMat, 
                      int *row_idx, vector<int> &col_idx,
-                     NumericVector &center, NumericVector &scale,
+                     NumericVector &center, NumericVector &scale, double *a,
                      double lambda, double sumResid, double alpha, 
                      double *r, double *m, int n, int p);
 
@@ -48,18 +39,16 @@ void update_zj(vector<double> &z,
 
 // check rest set with bedpp screening
 int check_rest_set_hsr_bedpp(int *e1, int *e2, int *reject, vector<double> &z, 
-                            XPtr<BigMatrix> xpMat, 
-                            int *row_idx,vector<int> &col_idx,
-                            NumericVector &center, 
-                            NumericVector &scale, double lambda, 
-                            double sumResid, double alpha, double *r, 
+                            XPtr<BigMatrix> xpMat, int *row_idx,vector<int> &col_idx,
+                            NumericVector &center, NumericVector &scale, double *a,
+                            double lambda, double sumResid, double alpha, double *r, 
                             double *m, int n, int p) {
   
   MatrixAccessor<double> xAcc(*xpMat);
-  double *xCol, sum, l1;
+  double *xCol, sum, l1, l2;
   int j, jj, violations = 0;
   
-  #pragma omp parallel for private(j, sum, l1) reduction(+:violations) schedule(static) 
+  #pragma omp parallel for private(j, sum, l1, l2) reduction(+:violations) schedule(static) 
   for (j = 0; j < p; j++) {
     if (reject[j] == 0 && e2[j] == 0) { // set not rejected by bedpp but by hsr
       jj = col_idx[j];
@@ -71,7 +60,8 @@ int check_rest_set_hsr_bedpp(int *e1, int *e2, int *reject, vector<double> &z,
       z[j] = (sum - center[jj] * sumResid) / (scale[jj] * n);
      
       l1 = lambda * m[jj] * alpha;
-      if(fabs(z[j]) > l1) {
+      l2 = lambda * m[jj] * (1 - alpha);
+      if (fabs(z[j] - a[j] * l2) > l1) {
         e1[j] = e2[j] = 1;
         violations++;
       }
@@ -298,13 +288,11 @@ RcppExport SEXP cdfit_gaussian_hsr_bedpp(SEXP X_, SEXP y_, SEXP row_idx_,
     }
     
     if (bedpp) {
-      bedpp_screen(bedpp_reject, sign_lammax_xtxmax, xty, ynorm_sq, row_idx, 
-                   col_idx, lambda[l], lambda_max, alpha, n, p);
+      bedpp_screen(bedpp_reject, sign_lammax_xtxmax, xty, ynorm_sq, row_idx, col_idx, lambda[l], lambda_max, alpha, n, p);
       n_bedpp_reject[l] = sum(bedpp_reject, p);
       
       // update z[j] for features which are rejected at previous lambda but accepted at current one.
-      update_zj(z, bedpp_reject, bedpp_reject_old, xMat, row_idx, col_idx, 
-                center, scale, sumResid, r, m, n, p);
+      update_zj(z, bedpp_reject, bedpp_reject_old, xMat, row_idx, col_idx, center, scale, sumResid, r, m, n, p);
 
       #pragma omp parallel for private(j) schedule(static) 
       for (j = 0; j < p; j++) {
@@ -365,21 +353,15 @@ RcppExport SEXP cdfit_gaussian_hsr_bedpp(SEXP X_, SEXP y_, SEXP row_idx_,
         }
         
         // Scan for violations in strong set
-        violations = check_strong_set(e1, e2, z, xMat, row_idx, col_idx,
-                                      center, scale, lambda[l], sumResid, 
-                                      alpha, r, m, n, p);
+        violations = check_strong_set(e1, e2, z, xMat, row_idx, col_idx, center, scale, a, lambda[l], sumResid, alpha, r, m, n, p);
         if (violations == 0) break;
       }
       
       // Scan for violations in rest set
       if (bedpp) {
-        violations = check_rest_set_hsr_bedpp(e1, e2, bedpp_reject, z, xMat, 
-                                             row_idx, col_idx,
-                                             center, scale, lambda[l], 
-                                             sumResid, alpha, r, m, n, p);
+        violations = check_rest_set_hsr_bedpp(e1, e2, bedpp_reject, z, xMat, row_idx, col_idx,center, scale, a, lambda[l], sumResid, alpha, r, m, n, p);
       } else {
-        violations = check_rest_set(e1, e2, z, xMat, row_idx, col_idx, center,  
-                                    scale, lambda[l], sumResid, alpha, r, m, n, p);
+        violations = check_rest_set(e1, e2, z, xMat, row_idx, col_idx, center, scale, a, lambda[l], sumResid, alpha, r, m, n, p);
       }
       
       if (violations == 0) {
@@ -396,7 +378,6 @@ RcppExport SEXP cdfit_gaussian_hsr_bedpp(SEXP X_, SEXP y_, SEXP row_idx_,
   Free_memo_hsr(a, r, e1, e2);
   Free(bedpp_reject);
   Free(bedpp_reject_old);
-  return List::create(beta, center, scale, lambda, loss, iter, 
-                      n_reject, n_bedpp_reject, Rcpp::wrap(col_idx));
+  return List::create(beta, center, scale, lambda, loss, iter, n_reject, n_bedpp_reject, Rcpp::wrap(col_idx));
 }
 
